@@ -15,7 +15,7 @@ has migrations      => sub {
 };
 has url             => sub { Mojo::MySQL5::URL->new('mysql:///test') };
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub db {
   my $self = shift;
@@ -37,7 +37,8 @@ sub db {
 sub from_string {
   my ($self, $str) = @_;
   my $url = Mojo::MySQL5::URL->new($str);
-  croak qq{Invalid MySQL connection string "$str"} unless $url->protocol eq 'mysql';
+  croak qq{Invalid MySQL connection string "$str"}
+    unless $url->protocol eq 'mysql' or $url->protocol eq 'mysql5';
 
   $url->options->{utf8} = 1 unless exists $url->options->{utf8};
   $url->options->{found_rows} = 1 unless exists $url->options->{found_rows};
@@ -224,9 +225,11 @@ easily.
 
 MySQL does not support nested transactions and DDL transactions.
 DDL statements cause implicit C<COMMIT>. C<ROLLBACK> will be called if
-any step of migration script fails, but only DML statements can be reverted.
+any step of migration script fails, but only DML statements after the
+last implicit or explicit C<COMMIT> can be reverted.
+Not all MySQL storage engines (like C<MYISAM>) support transactions.
 
-This means database can be left in unknown state if migration script fails.
+This means database will most likely be left in unknown state if migration script fails.
 Use this feature with caution and remember to always backup your database.
 
 =head2 url
